@@ -80,6 +80,7 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "OpenMonitoringInfoTypeDef",
     "PaginatorConfigTypeDef",
+    "RebootBrokerResponseTypeDef",
     "UpdateBrokerCountResponseTypeDef",
     "UpdateBrokerStorageResponseTypeDef",
     "UpdateClusterConfigurationResponseTypeDef",
@@ -474,6 +475,10 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
+RebootBrokerResponseTypeDef = TypedDict(
+    "RebootBrokerResponseTypeDef", {"ClusterArn": str, "ClusterOperationArn": str}, total=False
+)
+
 UpdateBrokerCountResponseTypeDef = TypedDict(
     "UpdateBrokerCountResponseTypeDef", {"ClusterArn": str, "ClusterOperationArn": str}, total=False
 )
